@@ -82,7 +82,7 @@ def do_remove_extension(*args):
                     "import coverage; print(coverage.__file__)",
                 ],
                 encoding="utf-8",
-            ).strip()
+            ).strip(),
         )
         roots = [root]
     else:
@@ -155,9 +155,9 @@ def should_skip(core):
 def make_env_id(core):
     """An environment id that will keep all the test runs distinct."""
     impl = platform.python_implementation().lower()
-    version = "%s%s" % sys.version_info[:2]
+    version = "{}{}".format(*sys.version_info[:2])
     if PYPY:
-        version += "_%s%s" % sys.pypy_version_info[:2]
+        version += "_{}{}".format(*sys.pypy_version_info[:2])
     env_id = f"{impl}{version}_{core}"
     return env_id
 
@@ -245,9 +245,10 @@ def do_combine_html():
     cov = coverage.Coverage(config_file="metacov.ini", messages=True)
     cov.load()
     show_contexts = bool(
-        os.getenv("COVERAGE_DYNCTX") or os.getenv("COVERAGE_CONTEXT")
+        os.getenv("COVERAGE_DYNCTX") or os.getenv("COVERAGE_CONTEXT"),
     )
     cov.html_report(show_contexts=show_contexts)
+    cov.json_report(show_contexts=show_contexts, pretty_print=True)
 
 
 def do_test_with_core(core, *runner_args):
@@ -280,7 +281,7 @@ def do_zip_mods():
             assert [ord(c) for c in text] == ords
             print(u"All OK with {encoding}")
             encoding = "{encoding}"
-            """
+            """,
         )
         # These encodings should match the list in tests/test_python.py
         details = [
@@ -333,7 +334,7 @@ def print_banner(label):
 def do_quietly(command):
     """Run a command in a shell, and suppress all output."""
     proc = subprocess.run(
-        command, shell=True, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL
+        command, shell=True, stdout=subprocess.DEVNULL, stderr=subprocess.DEVNULL,
     )
     return proc.returncode
 
@@ -388,7 +389,7 @@ def do_edit_for_release():
 
     # NOTICE.txt
     update_file(
-        "NOTICE.txt", r"Copyright 2004.*? Ned", f"Copyright 2004-{facts.now:%Y} Ned"
+        "NOTICE.txt", r"Copyright 2004.*? Ned", f"Copyright 2004-{facts.now:%Y} Ned",
     )
 
     # CHANGES.rst
@@ -411,7 +412,7 @@ def do_edit_for_release():
         # The date of release, in "monthname day, year" format.
         release_date = "{facts.now:%B %-d, %Y}"
         # @@@ end
-        """
+        """,
     )
     update_file("doc/conf.py", r"(?s)# @@@ editable\n.*# @@@ end\n", new_conf)
 
@@ -430,7 +431,7 @@ def do_bump_version():
     # coverage/version.py
     next_version = f"version_info = {facts.next_vi}\n_dev = 1".replace("'", '"')
     update_file(
-        "coverage/version.py", r"(?m)^version_info = .*\n_dev = \d+$", next_version
+        "coverage/version.py", r"(?m)^version_info = .*\n_dev = \d+$", next_version,
     )
 
 
@@ -445,27 +446,31 @@ def do_cheats():
     github = f"https://github.com/{repo}"
     egg = "egg=coverage==0.0"  # to force a re-install
     print(
-        f"https://coverage.readthedocs.io/en/{facts.ver}/changes.html#changes-{facts.anchor}"
+        f"https://coverage.readthedocs.io/en/{facts.ver}/changes.html#changes-{facts.anchor}",
     )
 
     print(
         "\n## For GitHub commenting:\n"
         + "This is now released as part of "
-        + f"[coverage {facts.ver}](https://pypi.org/project/coverage/{facts.ver})."
+        + f"[coverage {facts.ver}](https://pypi.org/project/coverage/{facts.ver}).",
     )
 
-    print("\n## To run this code:")
+    print("\n## To install this code:")
     if facts.branch == "master":
         print(f"python3 -m pip install git+{github}#{egg}")
     else:
         print(f"python3 -m pip install git+{github}@{facts.branch}#{egg}")
     print(f"python3 -m pip install git+{github}@{facts.sha[:20]}#{egg}")
 
+    print("\n## To read this code on GitHub:")
+    print(f"https://github.com/nedbat/coveragepy/commit/{facts.sha}")
+    print(f"https://github.com/nedbat/coveragepy/commits/{facts.sha}")
+
     print(
-        "\n## For other collaborators:\n"
+        "\n## For other collaborators to get this code:\n"
         + f"git clone {github}\n"
         + f"cd {repo.partition('/')[-1]}\n"
-        + f"git checkout {facts.sha}"
+        + f"git checkout {facts.sha}",
     )
 
 
